@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 import subprocess
-#from python_sureshmnv.logging_sureshmnv import *
-from logging_sureshmnv import *
+from python_sureshmnv.logging_sureshmnv import *
+#from logging_sureshmnv import *
 
 print('name of module in subproces global is', __name__)
 logger = logging_mnv_set(logName=__name__, logLevel=logging.DEBUG)
